==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebColumnVisibilityChangingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata } from "./WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata";
import { WebColumnVisibilityChangingEventArgsDescription } from "./WebColumnVisibilityChangingEventArgsDescription";
/**
 * @hidden
 */
var WebColumnVisibilityChangingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebColumnVisibilityChangingEventArgsDescriptionMetadata, _super);
    function WebColumnVisibilityChangingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnVisibilityChangingEventArgsDescriptionMetadata.b = function (a) {
        if (WebColumnVisibilityChangingEventArgsDescriptionMetadata.a == null) {
            WebColumnVisibilityChangingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnVisibilityChangingEventArgsDescriptionMetadata.c(WebColumnVisibilityChangingEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebColumnVisibilityChangingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebColumnVisibilityChangingEventArgsDescriptionMetadata.a);
        WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.d(a);
    };
    WebColumnVisibilityChangingEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ColumnVisibilityChangingEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebColumnVisibilityChangingEventArgsDetail");
    };
    WebColumnVisibilityChangingEventArgsDescriptionMetadata.d = function (a) {
        WebColumnVisibilityChangingEventArgsDescriptionMetadata.b(a);
        a.ad("WebColumnVisibilityChangingEventArgs", function () { return new WebColumnVisibilityChangingEventArgsDescription(); });
        a.ac("WebColumnVisibilityChangingEventArgs", WebColumnVisibilityChangingEventArgsDescriptionMetadata.a);
    };
    WebColumnVisibilityChangingEventArgsDescriptionMetadata.$t = markType(WebColumnVisibilityChangingEventArgsDescriptionMetadata, 'WebColumnVisibilityChangingEventArgsDescriptionMetadata');
    WebColumnVisibilityChangingEventArgsDescriptionMetadata.a = null;
    return WebColumnVisibilityChangingEventArgsDescriptionMetadata;
}(Base));
export { WebColumnVisibilityChangingEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebColumnVisibilityChangingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata } from "./WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata";
import { WebColumnVisibilityChangingEventArgsDescription } from "./WebColumnVisibilityChangingEventArgsDescription";
/**
 * @hidden
 */
var WebColumnVisibilityChangingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebColumnVisibilityChangingEventArgsDescriptionMetadata, _super);
    function WebColumnVisibilityChangingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnVisibilityChangingEventArgsDescriptionMetadata.b = function (a) {
        if (WebColumnVisibilityChangingEventArgsDescriptionMetadata.a == null) {
            WebColumnVisibilityChangingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnVisibilityChangingEventArgsDescriptionMetadata.c(WebColumnVisibilityChangingEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebColumnVisibilityChangingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebColumnVisibilityChangingEventArgsDescriptionMetadata.a);
        WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.d(a);
    };
    WebColumnVisibilityChangingEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ColumnVisibilityChangingEventArgs");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebColumnVisibilityChangingEventArgsDetail");
    };
    WebColumnVisibilityChangingEventArgsDescriptionMetadata.d = function (a) {
        WebColumnVisibilityChangingEventArgsDescriptionMetadata.b(a);
        a.ae("WebColumnVisibilityChangingEventArgs", function () { return new WebColumnVisibilityChangingEventArgsDescription(); });
        a.ad("WebColumnVisibilityChangingEventArgs", WebColumnVisibilityChangingEventArgsDescriptionMetadata.a);
    };
    WebColumnVisibilityChangingEventArgsDescriptionMetadata.$t = markType(WebColumnVisibilityChangingEventArgsDescriptionMetadata, 'WebColumnVisibilityChangingEventArgsDescriptionMetadata');
    WebColumnVisibilityChangingEventArgsDescriptionMetadata.a = null;
    return WebColumnVisibilityChangingEventArgsDescriptionMetadata;
}(Base));
export { WebColumnVisibilityChangingEventArgsDescriptionMetadata };
